@@ -2,12 +2,14 @@ import re
 
 from typing import Pattern
 
+from faker.providers.automotive import calculate_vin_str_weight
 from faker.providers.automotive.de_DE import Provider as DeDeAutomotiveProvider
 from faker.providers.automotive.es_ES import Provider as EsEsAutomotiveProvider
 from faker.providers.automotive.ro_RO import Provider as RoRoAutomotiveProvider
 from faker.providers.automotive.ru_RU import Provider as RuRuAutomotiveProvider
 from faker.providers.automotive.sk_SK import Provider as SkSkAutomotiveProvider
 from faker.providers.automotive.tr_TR import Provider as TrTrAutomotiveProvider
+from faker.providers.automotive.uk_UA import Provider as UkUaAutomotiveProvider
 
 
 class _SimpleAutomotiveTestMixin:
@@ -23,6 +25,19 @@ class _SimpleAutomotiveTestMixin:
             assert match is not None
             self.perform_extra_checks(license_plate, match)
 
+    def test_vin(self, faker, num_samples):
+        for _ in range(num_samples):
+            vin_number = faker.vin()
+            # length check: 17
+            assert len(vin_number) == 17
+
+            # verify checksum: vin_number[8]
+            front_part_weight = calculate_vin_str_weight(vin_number[:8], [8, 7, 6, 5, 4, 3, 2, 10])
+            rear_part_weight = calculate_vin_str_weight(vin_number[9:], [9, 8, 7, 6, 5, 4, 3, 2])
+            checksum = (front_part_weight + rear_part_weight) % 11
+            checksum_str = "X" if checksum == 10 else str(checksum)
+            assert vin_number[8] == checksum_str
+
 
 class TestArBh(_SimpleAutomotiveTestMixin):
     """Test ar_BH automotive provider methods"""
@@ -333,3 +348,35 @@ class TestZhTw(_SimpleAutomotiveTestMixin):
         r"([A-Z]{3}-\d{4})|"  # new format since 2014
         r"([A-Z]{3}-\d{3})",  # commercial cars since 2012
     )
+
+
+class TestUkUa(_SimpleAutomotiveTestMixin):
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}\d{4}[A-Z]{2}")
+
+    def perform_extra_checks(self, license_plate, match):
+        assert license_plate[-2:] in UkUaAutomotiveProvider.license_plate_suffix
+
+    def test_temporary_plate(self, faker, num_samples):
+        pattern = r"\d{2} [A-Z]{2}\d{4}"
+
+        for _ in range(num_samples):
+            temporary = faker.license_plate(temporary_plate=True)
+            match = re.search(pattern, temporary)
+            assert match is not None
+
+    def test_diplomatic_plate(self, faker, num_samples):
+        pattern = r"(CDP \d{3})|(DP|S) \d{3} \d{3}"
+
+        for _ in range(num_samples):
+            temporary = faker.diplomatic_license_plate()
+            match = re.search(pattern, temporary)
+            assert match is not None
+
+    def test_prefix(self, faker):
+        for _ in range(10):
+            temporary = faker.plate_letter_prefix(region_name="Lviv")
+            assert len(temporary) == 2
+            assert temporary in UkUaAutomotiveProvider.license_region_data.get("Lviv")[0]
+
+    def test_region_code(self, faker):
+        assert "14" == faker.plate_region_code(region_name="Lviv")
